@@ -43,13 +43,36 @@ Execp *create_execp()
     execp->backend->cache_icon = TRUE;
     execp->backend->centered = TRUE;
     execp->backend->font_color.alpha = 0.5;
+    execp->backend->monitor = -1;
     INIT_TIMER(execp->backend->timer);
+    execp->backend->bg = &g_array_index(backgrounds, Background, 0);
+    execp->backend->buf_stdout_capacity = 1024;
+    execp->backend->buf_stdout = calloc(execp->backend->buf_stdout_capacity, 1);
+    execp->backend->buf_stderr_capacity = 1024;
+    execp->backend->buf_stderr = calloc(execp->backend->buf_stderr_capacity, 1);
+    execp->backend->text = strdup("");
+    execp->backend->icon_path = NULL;
     return execp;
 }
 
 gpointer create_execp_frontend(gconstpointer arg, gpointer data)
 {
     Execp *execp_backend = (Execp *)arg;
+    Panel *panel = data;
+    if (execp_backend->backend->monitor >= 0 &&
+        panel->monitor != execp_backend->backend->monitor) {
+        printf("Skipping executor '%s' with monitor %d for panel on monitor %d\n",
+               execp_backend->backend->command,
+               execp_backend->backend->monitor, panel->monitor);
+        Execp *dummy = create_execp();
+        dummy->frontend = (ExecpFrontend *)calloc(1, sizeof(ExecpFrontend));
+        dummy->backend->instances = g_list_append(dummy->backend->instances, dummy);
+        dummy->dummy = true;
+        return dummy;
+    }
+    printf("Creating executor '%s' with monitor %d for panel on monitor %d\n",
+           execp_backend->backend->command,
+           execp_backend->backend->monitor, panel->monitor);
 
     Execp *execp_frontend = (Execp *)calloc(1, sizeof(Execp));
     execp_frontend->backend = execp_backend->backend;
@@ -67,7 +90,11 @@ void destroy_execp(void *obj)
         free_and_null(execp->frontend);
         remove_area(&execp->area);
         free_area(&execp->area);
-        free_and_null(execp);
+        if (execp->dummy) {
+            destroy_execp(execp);
+        } else {
+            free_and_null(execp);
+        }
     } else {
         // This is a backend element
         destroy_timer(&execp->backend->timer);
@@ -144,12 +171,6 @@ void init_execp()
         // Set missing config options
         if (!execp->backend->bg)
             execp->backend->bg = &g_array_index(backgrounds, Background, 0);
-        execp->backend->buf_stdout_capacity = 1024;
-        execp->backend->buf_stdout = calloc(execp->backend->buf_stdout_capacity, 1);
-        execp->backend->buf_stderr_capacity = 1024;
-        execp->backend->buf_stderr = calloc(execp->backend->buf_stderr_capacity, 1);
-        execp->backend->text = strdup("");
-        execp->backend->icon_path = NULL;
     }
 }
 
@@ -163,7 +184,7 @@ void init_execp_panel(void *p)
 
     // panel->execp_list is now a copy of the pointer panel_config.execp_list
     // We make it a deep copy
-    panel->execp_list = g_list_copy_deep(panel_config.execp_list, create_execp_frontend, NULL);
+    panel->execp_list = g_list_copy_deep(panel_config.execp_list, create_execp_frontend, panel);
 
     for (GList *l = panel->execp_list; l; l = l->next) {
         Execp *execp = l->data;
