@@ -389,9 +389,9 @@ gboolean handle_x_event_autohide(XEvent *e)
     Panel *panel = get_panel(e->xany.window);
     if (panel && panel_autohide) {
         if (e->type == EnterNotify)
-            autohide_trigger_show(panel);
+            autohide_trigger_show(panel, e->xany.send_event);
         else if (e->type == LeaveNotify)
-            autohide_trigger_hide(panel);
+            autohide_trigger_hide(panel, e->xany.send_event);
         if (panel->is_hidden) {
             if (e->type == ClientMessage && e->xclient.message_type == server.atom.XdndPosition) {
                 hidden_panel_shown_for_dnd = TRUE;
