@@ -269,8 +269,9 @@ void init_panel()
                 init_freespace_panel(p);
             if (panel_items_order[k] == ':')
                 init_separator_panel(p);
-            if (panel_items_order[k] == 'E')
+            if (panel_items_order[k] == 'E') {
                 init_execp_panel(p);
+            }
             if (panel_items_order[k] == 'P')
                 init_button_panel(p);
         }
@@ -316,7 +317,7 @@ void init_panel()
         }
 
         if (panel_autohide)
-            autohide_trigger_hide(p);
+            autohide_trigger_hide(p, false);
     }
 
     taskbar_refresh_tasklist();
@@ -1139,26 +1140,27 @@ void autohide_hide(void *p)
     schedule_panel_redraw();
 }
 
-void autohide_trigger_show(Panel *p)
+void autohide_trigger_show(Panel *p, bool forced)
 {
     if (!p)
         return;
-    change_timer(&p->autohide_timer, true, panel_autohide_show_timeout, 0, autohide_show, p);
+    change_timer(&p->autohide_timer, true, forced ? 0 : panel_autohide_show_timeout, 0, autohide_show, p);
 }
 
-void autohide_trigger_hide(Panel *p)
+void autohide_trigger_hide(Panel *p, bool forced)
 {
     if (!p)
         return;
 
-    Window root, child;
-    int xr, yr, xw, yw;
-    unsigned int mask;
-    if (XQueryPointer(server.display, p->main_win, &root, &child, &xr, &yr, &xw, &yw, &mask))
-        if (child)
-            return; // mouse over one of the system tray icons
-
-    change_timer(&p->autohide_timer, true, panel_autohide_hide_timeout, 0, autohide_hide, p);
+    if (!forced) {
+        Window root, child;
+        int xr, yr, xw, yw;
+        unsigned int mask;
+        if (XQueryPointer(server.display, p->main_win, &root, &child, &xr, &yr, &xw, &yw, &mask))
+            if (child)
+                return; // mouse over one of the system tray icons
+    }
+    change_timer(&p->autohide_timer, true, forced ? 0 : panel_autohide_hide_timeout, 0, autohide_hide, p);
 }
 
 void shrink_panel(Panel *panel)
